# SymNet Control Protocol implementation

This is an asyncio implementation of the [SymNet Control Protocol](https://www.symetrix.co/repository/SymNet_cp.pdf).
At bermudafunk we use this to control a Solus 16x8.
